/** cem.c is part of JamMo.
License: GPLv2, read more from COPYING

(from D2.4)
CEM is started as JamMo is started as it is used to log user actions in
all use cases. Mentor and games components only need to be started if
the use case is correct.
*/
#include <stdio.h>
#include "cem.h"

//very STUB logging function
void cem_add_to_log(char *message,int type){
  if (type==LOG_DEBUG) {
    printf("**DEBUG: %s **\n",message);
  }else if(type==LOG_ERROR){
    printf("**ERROR: %s **\n",message);
  }else if(type==LOG_NETWORK_DEBUG){
  	printf("**NETWORK DEBUG: %s**\n",message);
  }else if(type==LOG_NETWORK){
	  printf("**NETWORKING: %s**\n",message);
  }else{
    printf("**MESSAGE: %s **\n",message);
  }
}
